==> dnet-openaireplus-workflows-6.0.13-20170410.072506-9-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/FeedMissingClaimsJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;
import eu.dnetlib.data.index.CloudIndexClient;
import eu.dnetlib.data.index.CloudIndexClientFactory;
import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.miscutils.functional.xml.ApplyXslt;
import eu.dnetlib.msro.openaireplus.api.RecentPublicationsQueue;
import eu.dnetlib.msro.openaireplus.utils.OafToIndexRecordFactory;
import eu.dnetlib.msro.rmi.MSROException;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;
import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.solr.common.SolrInputDocument;
import org.dom4j.io.SAXReader;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;

/**
 * Created by michele on 15/12/15.
 */
public class FeedMissingClaimsJobNode extends AsyncJobNode {

	private static final Log log = LogFactory.getLog(FeedMissingClaimsJobNode.class);
	private RecentPublicationsQueue queue;
	private OafToIndexRecordFactory oafToIndexRecordFactory;

	@Resource
	private UniqueServiceLocator serviceLocator;

	@Value(value = "${openaireplus.msro.api.findSolrIndexUrl.xquery}")
	private ClassPathResource findSolrIndexUrl;

	@Override
	protected String execute(final NodeToken nodeToken) throws Exception {

		final String format =
				nodeToken.getEnv().hasAttribute("format") ? nodeToken.getEnv().getAttribute("format") : nodeToken.getFullEnv().getAttribute("format");
		final String coll = format + "-index-openaire";
		final String indexDsId = nodeToken.getEnv().getAttribute("index_id");
		final String baseUrl = calculateIndexBaseUrl();

		CloudIndexClient idxClient = null;

		try {
			final List<SolrInputDocument> toFeed = new ArrayList<SolrInputDocument>();
			final List<String> toDeleteFromCache = new ArrayList<String>();

			final SAXReader reader = new SAXReader();
			final ApplyXslt xslt = oafToIndexRecordFactory.newTransformer(format);

			idxClient = CloudIndexClientFactory.newIndexClient(baseUrl, coll, false);

			for (String record : queue) {
				final String id = reader.read(new StringReader(record)).valueOf("//*[local-name() = 'objIdentifier']");
				if (idxClient.isRecordIndexed(id)) {
					toDeleteFromCache.add(id);
				} else {
					toFeed.add(idxClient.prepareSolrDocument(record, indexDsId, xslt));
				}
			}

			idxClient.feed(toFeed, null);
			queue.remove(toDeleteFromCache);

		} catch (Throwable e) {
			log.error("Error feeding missing claims", e);
			throw new MSROException("Error feeding missing claims: " + e.getMessage(), e);
		} finally {
			if (idxClient != null) {
				idxClient.close();
			}
		}

		return Arc.DEFAULT_ARC;
	}

	public RecentPublicationsQueue getQueue() {
		return queue;
	}

	@Required
	public void setQueue(final RecentPublicationsQueue queue) {
		this.queue = queue;
	}

	public OafToIndexRecordFactory getOafToIndexRecordFactory() {
		return oafToIndexRecordFactory;
	}

	@Required
	public void setOafToIndexRecordFactory(final OafToIndexRecordFactory oafToIndexRecordFactory) {
		this.oafToIndexRecordFactory = oafToIndexRecordFactory;
	}

	private String calculateIndexBaseUrl() throws Exception {
		final String query = IOUtils.toString(findSolrIndexUrl.getInputStream());
		return serviceLocator.getService(ISLookUpService.class).getResourceProfileByQuery(query);
	}
}

==> dnet-openaireplus-workflows-6.1.2-20171024.155315-23-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/FeedMissingClaimsJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import java.io.StringReader;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Resource;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;
import eu.dnetlib.data.index.CloudIndexClient;
import eu.dnetlib.data.index.CloudIndexClientFactory;
import eu.dnetlib.enabling.is.lookup.rmi.ISLookUpService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.miscutils.functional.xml.ApplyXslt;
import eu.dnetlib.msro.openaireplus.api.RecentResultsQueue;
import eu.dnetlib.msro.openaireplus.utils.OafToIndexRecordFactory;
import eu.dnetlib.msro.rmi.MSROException;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;
import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.solr.common.SolrInputDocument;
import org.dom4j.io.SAXReader;
import org.springframework.beans.factory.annotation.Required;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;

/**
 * Created by michele on 15/12/15.
 */
public class FeedMissingClaimsJobNode extends AsyncJobNode {

	private static final Log log = LogFactory.getLog(FeedMissingClaimsJobNode.class);
	private RecentResultsQueue queue;
	private OafToIndexRecordFactory oafToIndexRecordFactory;

	@Resource
	private UniqueServiceLocator serviceLocator;

	@Value(value = "${openaireplus.msro.api.findSolrIndexUrl.xquery}")
	private ClassPathResource findSolrIndexUrl;

	@Override
	protected String execute(final NodeToken nodeToken) throws Exception {

		final String format =
				nodeToken.getEnv().hasAttribute("format") ? nodeToken.getEnv().getAttribute("format") : nodeToken.getFullEnv().getAttribute("format");
		final String coll = format + "-index-openaire";
		final String indexDsId = nodeToken.getEnv().getAttribute("index_id");
		final String baseUrl = calculateIndexBaseUrl();

		CloudIndexClient idxClient = null;

		try {
			final List<SolrInputDocument> toFeed = new ArrayList<SolrInputDocument>();
			final List<String> toDeleteFromCache = new ArrayList<String>();

			final SAXReader reader = new SAXReader();
			final ApplyXslt xslt = oafToIndexRecordFactory.newTransformer(format);

			idxClient = CloudIndexClientFactory.newIndexClient(baseUrl, coll, false);

			for (String record : queue) {
				final String id = reader.read(new StringReader(record)).valueOf("//*[local-name() = 'objIdentifier']");
				if (idxClient.isRecordIndexed(id)) {
					toDeleteFromCache.add(id);
				} else {
					toFeed.add(idxClient.prepareSolrDocument(record, indexDsId, xslt));
				}
			}

			idxClient.feed(toFeed, null);
			queue.remove(toDeleteFromCache);

		} catch (Throwable e) {
			log.error("Error feeding missing claims", e);
			throw new MSROException("Error feeding missing claims: " + e.getMessage(), e);
		} finally {
			if (idxClient != null) {
				idxClient.close();
			}
		}

		return Arc.DEFAULT_ARC;
	}

	public RecentResultsQueue getQueue() {
		return queue;
	}

	@Required
	public void setQueue(final RecentResultsQueue queue) {
		this.queue = queue;
	}

	public OafToIndexRecordFactory getOafToIndexRecordFactory() {
		return oafToIndexRecordFactory;
	}

	@Required
	public void setOafToIndexRecordFactory(final OafToIndexRecordFactory oafToIndexRecordFactory) {
		this.oafToIndexRecordFactory = oafToIndexRecordFactory;
	}

	private String calculateIndexBaseUrl() throws Exception {
		final String query = IOUtils.toString(findSolrIndexUrl.getInputStream());
		return serviceLocator.getService(ISLookUpService.class).getResourceProfileByQuery(query);
	}
}
